pub struct AsyncBufferGlobalReader<IP: MatrixPrecision, S: StageConfig, CM: CopyMechanism, L: AsyncPartialLoadingStrategy> { /* private fields */ }Expand description
Loads a stage from stage memory using asynchronous data movement operations.
A complete load is referred to as a Job, which is divided into Tasks—
each Task represents a single data transfer for a specific unit
Implementations
Sourceimpl<IP: MatrixPrecision, S: StageConfig, CM: CopyMechanism, L: AsyncPartialLoadingStrategy> AsyncBufferGlobalReader<IP, S, CM, L>
impl<IP: MatrixPrecision, S: StageConfig, CM: CopyMechanism, L: AsyncPartialLoadingStrategy> AsyncBufferGlobalReader<IP, S, CM, L>
Sourcepub fn new(
tensor: View<Line<IP::Global>, Coords2d>,
k_step: u32,
ident: MatmulIdent,
config: DoubleBufferingGlobalConfig<S>,
) -> Self
pub fn new( tensor: View<Line<IP::Global>, Coords2d>, k_step: u32, ident: MatmulIdent, config: DoubleBufferingGlobalConfig<S>, ) -> Self
Create a new AsyncBufferGlobalReader
Sourcepub fn stage(
&mut self,
stage_buffer: StageBuffer,
) -> StridedStage<IP::Stage, L::TilingLayout>
pub fn stage( &mut self, stage_buffer: StageBuffer, ) -> StridedStage<IP::Stage, L::TilingLayout>
Give a reader to the loaded stage memory.
Sourcepub fn advance_view(&mut self)
pub fn advance_view(&mut self)
Advance the view over global memory along the k dimension.
Sourcepub fn load_stage(
&mut self,
mechanism: &CM,
stage_buffer: StageBuffer,
config: DoubleBufferingGlobalConfig<S>,
)
pub fn load_stage( &mut self, mechanism: &CM, stage_buffer: StageBuffer, config: DoubleBufferingGlobalConfig<S>, )
Accomplish the entire job of loading data into the stage memory
Sourcepub fn clear_stage(
&mut self,
stage_buffer: StageBuffer,
config: DoubleBufferingGlobalConfig<S>,
)
pub fn clear_stage( &mut self, stage_buffer: StageBuffer, config: DoubleBufferingGlobalConfig<S>, )
Zero out the stage memory
pub fn __expand_new( scope: &mut Scope, tensor: <View<Line<IP::Global>, Coords2d> as CubeType>::ExpandType, k_step: <u32 as CubeType>::ExpandType, ident: MatmulIdent, config: DoubleBufferingGlobalConfig<S>, ) -> <Self as CubeType>::ExpandType
pub fn __expand_stage( scope: &mut Scope, this: <Self as CubeType>::ExpandType, stage_buffer: StageBuffer, ) -> <StridedStage<IP::Stage, L::TilingLayout> as CubeType>::ExpandType
pub fn __expand_advance_view( scope: &mut Scope, this: <Self as CubeType>::ExpandType, ) -> <() as CubeType>::ExpandType
pub fn __expand_load_stage( scope: &mut Scope, this: <Self as CubeType>::ExpandType, mechanism: <CM as CubeType>::ExpandType, stage_buffer: StageBuffer, config: DoubleBufferingGlobalConfig<S>, ) -> <() as CubeType>::ExpandType
pub fn __expand_clear_stage( scope: &mut Scope, this: <Self as CubeType>::ExpandType, stage_buffer: StageBuffer, config: DoubleBufferingGlobalConfig<S>, ) -> <() as CubeType>::ExpandType